@@ -10,14 +10,14 @@ import networkx as nx
 from ase import Atoms
 from backports.cached_property import cached_property
 from networkx.algorithms.graph_hashing import weisfeiler_lehman_graph_hash
-from pymatgen.analysis.graphs import ConnectedSite, StructureGraph
-from pymatgen.core.structure import IStructure, Structure
-from pymatgen.io.ase import AseAtomsAdaptor
-from pymatgen.io.cif import CifParser
 
 from mofchecker.checks.local_structure.undercoordinated_rare_earth import (
     UnderCoordinatedRareEarthCheck,
 )
+from mofchecker.utils import IStructure, Structure
+from pymatgen.analysis.graphs import ConnectedSite, StructureGraph
+from pymatgen.io.ase import AseAtomsAdaptor
+from pymatgen.io.cif import CifParser
 
 from ._version import get_versions
 from .checks.charge_check import ChargeCheck
@@ -138,10 +138,10 @@ class MOFChecker:  # pylint:disable=too-many-instance-attributes, too-many-publi
             "no_overcoordinated_nitrogen": OverCoordinatedNitrogenCheck.from_mofchecker(
                 self
             ),
-            "no_undercoordinated_nitrogen": UnderCoordinatedNitrogenCheck.from_mofchecker(  # pylint: disable=line-too-long
+            "no_undercoordinated_nitrogen": UnderCoordinatedNitrogenCheck.from_mofchecker(
                 self
             ),
-            "no_undercoordinated_rare_earth": UnderCoordinatedRareEarthCheck.from_mofchecker(  # pylint: disable=line-too-long
+            "no_undercoordinated_rare_earth": UnderCoordinatedRareEarthCheck.from_mofchecker(
                 self
             ),
             "no_floating_molecule": FloatingSolventCheck.from_mofchecker(self),
